# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from lara_django_projects_grpc.v1 import lara_django_projects_pb2 as lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2


class ExperimentCalendarControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentCalendarController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentCalendarController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentCalendarController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentCalendarController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentCalendarController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ExperimentCalendarController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentCalendarController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
                _registered_method=True)


class ExperimentCalendarControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExperimentCalendarControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ExperimentCalendarController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ExperimentCalendarController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ExperimentCalendarController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentCalendarController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentCalendarController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentCalendarController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentCalendarController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentCalendarController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentCalendarController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentCalendarController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ExperimentControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.DownloadFile = channel.unary_stream(
                '/lara_django.lara_django_projects.ExperimentController/DownloadFile',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.FromString,
                _registered_method=True)
        self.DownloadImage = channel.unary_stream(
                '/lara_django.lara_django_projects.ExperimentController/DownloadImage',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
                _registered_method=True)
        self.RetrieveByNameNamespace = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentController/RetrieveByNameNamespace',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRetrieveByNameNSRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ExperimentController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
                _registered_method=True)
        self.UploadFile = channel.stream_unary(
                '/lara_django.lara_django_projects.ExperimentController/UploadFile',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.FromString,
                _registered_method=True)
        self.UploadImage = channel.stream_unary(
                '/lara_django.lara_django_projects.ExperimentController/UploadImage',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.FromString,
                _registered_method=True)


class ExperimentControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveByNameNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadFile(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadImage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExperimentControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.SerializeToString,
            ),
            'DownloadImage': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.SerializeToString,
            ),
            'RetrieveByNameNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveByNameNamespace,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRetrieveByNameNSRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.SerializeToString,
            ),
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.SerializeToString,
            ),
            'UploadImage': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadImage,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ExperimentController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ExperimentController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ExperimentController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/DownloadFile',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/DownloadImage',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RetrieveByNameNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/RetrieveByNameNamespace',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRetrieveByNameNSRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_projects.ExperimentController/UploadFile',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadImage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_projects.ExperimentController/UploadImage',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ExperimentsSubsetControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentsSubsetController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentsSubsetController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentsSubsetController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentsSubsetController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentsSubsetController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ExperimentsSubsetController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ExperimentsSubsetController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
                _registered_method=True)


class ExperimentsSubsetControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExperimentsSubsetControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ExperimentsSubsetController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ExperimentsSubsetController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ExperimentsSubsetController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentsSubsetController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentsSubsetController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentsSubsetController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentsSubsetController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentsSubsetController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentsSubsetController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ExperimentsSubsetController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ExperimentsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ProjectCalendarControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectCalendarController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectCalendarController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectCalendarController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectCalendarController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectCalendarController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ProjectCalendarController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectCalendarController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
                _registered_method=True)


class ProjectCalendarControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectCalendarControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ProjectCalendarController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ProjectCalendarController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectCalendarController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectCalendarController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectCalendarController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectCalendarController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectCalendarController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectCalendarController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectCalendarController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectCalendarController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectCalendarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ProjectControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.DownloadFile = channel.unary_stream(
                '/lara_django.lara_django_projects.ProjectController/DownloadFile',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.FromString,
                _registered_method=True)
        self.DownloadImage = channel.unary_stream(
                '/lara_django.lara_django_projects.ProjectController/DownloadImage',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
                _registered_method=True)
        self.RetrieveByNameNamespace = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectController/RetrieveByNameNamespace',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRetrieveByNameNSRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ProjectController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
                _registered_method=True)
        self.UploadFile = channel.stream_unary(
                '/lara_django.lara_django_projects.ProjectController/UploadFile',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.FromString,
                _registered_method=True)
        self.UploadImage = channel.stream_unary(
                '/lara_django.lara_django_projects.ProjectController/UploadImage',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.FromString,
                _registered_method=True)


class ProjectControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveByNameNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadFile(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadImage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.SerializeToString,
            ),
            'DownloadImage': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.SerializeToString,
            ),
            'RetrieveByNameNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveByNameNamespace,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRetrieveByNameNSRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.SerializeToString,
            ),
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.SerializeToString,
            ),
            'UploadImage': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadImage,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ProjectController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ProjectController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/DownloadFile',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/DownloadImage',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RetrieveByNameNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/RetrieveByNameNamespace',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRetrieveByNameNSRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_projects.ProjectController/UploadFile',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadImage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_projects.ProjectController/UploadImage',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ProjectSyncStatusControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSyncStatusController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSyncStatusController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSyncStatusController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSyncStatusController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSyncStatusController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ProjectSyncStatusController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSyncStatusController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
                _registered_method=True)


class ProjectSyncStatusControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectSyncStatusControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ProjectSyncStatusController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ProjectSyncStatusController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectSyncStatusController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSyncStatusController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSyncStatusController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSyncStatusController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSyncStatusController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSyncStatusController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSyncStatusController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSyncStatusController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSyncStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ProjectSynchronisationControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSynchronisationController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSynchronisationController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSynchronisationController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSynchronisationController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSynchronisationController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ProjectSynchronisationController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectSynchronisationController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
                _registered_method=True)


class ProjectSynchronisationControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectSynchronisationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ProjectSynchronisationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ProjectSynchronisationController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectSynchronisationController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSynchronisationController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSynchronisationController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSynchronisationController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSynchronisationController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSynchronisationController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSynchronisationController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectSynchronisationController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectSynchronisationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ProjectsSubsetControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectsSubsetController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectsSubsetController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectsSubsetController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectsSubsetController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectsSubsetController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.ProjectsSubsetController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.ProjectsSubsetController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
                _registered_method=True)


class ProjectsSubsetControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectsSubsetControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.ProjectsSubsetController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.ProjectsSubsetController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectsSubsetController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectsSubsetController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectsSubsetController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectsSubsetController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectsSubsetController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectsSubsetController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectsSubsetController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.ProjectsSubsetController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ProjectsSubsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class TaskControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/lara_django.lara_django_projects.TaskController/Create',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
                _registered_method=True)
        self.Destroy = channel.unary_unary(
                '/lara_django.lara_django_projects.TaskController/Destroy',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskDestroyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.DownloadFile = channel.unary_stream(
                '/lara_django.lara_django_projects.TaskController/DownloadFile',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.FromString,
                _registered_method=True)
        self.DownloadImage = channel.unary_stream(
                '/lara_django.lara_django_projects.TaskController/DownloadImage',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/lara_django.lara_django_projects.TaskController/List',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskListRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskListResponse.FromString,
                _registered_method=True)
        self.PartialUpdate = channel.unary_unary(
                '/lara_django.lara_django_projects.TaskController/PartialUpdate',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskPartialUpdateRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/lara_django.lara_django_projects.TaskController/Retrieve',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRetrieveRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
                _registered_method=True)
        self.RetrieveByNameNamespace = channel.unary_unary(
                '/lara_django.lara_django_projects.TaskController/RetrieveByNameNamespace',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRetrieveByNameNSRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
                _registered_method=True)
        self.Stream = channel.unary_stream(
                '/lara_django.lara_django_projects.TaskController/Stream',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskStreamRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/lara_django.lara_django_projects.TaskController/Update',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRequest.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
                _registered_method=True)
        self.UploadFile = channel.stream_unary(
                '/lara_django.lara_django_projects.TaskController/UploadFile',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.FromString,
                _registered_method=True)
        self.UploadImage = channel.stream_unary(
                '/lara_django.lara_django_projects.TaskController/UploadImage',
                request_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.SerializeToString,
                response_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.FromString,
                _registered_method=True)


class TaskControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Destroy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartialUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveByNameNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadFile(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadImage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TaskControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.SerializeToString,
            ),
            'Destroy': grpc.unary_unary_rpc_method_handler(
                    servicer.Destroy,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskDestroyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.SerializeToString,
            ),
            'DownloadImage': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskListRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskListResponse.SerializeToString,
            ),
            'PartialUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.PartialUpdate,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskPartialUpdateRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRetrieveRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.SerializeToString,
            ),
            'RetrieveByNameNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveByNameNamespace,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRetrieveByNameNSRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskStreamRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRequest.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.SerializeToString,
            ),
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.SerializeToString,
            ),
            'UploadImage': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadImage,
                    request_deserializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.FromString,
                    response_serializer=lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'lara_django.lara_django_projects.TaskController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('lara_django.lara_django_projects.TaskController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TaskController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/Create',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Destroy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/Destroy',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskDestroyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/DownloadFile',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadInfo.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/DownloadImage',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadInfo.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageDownloadChunk.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/List',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskListRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PartialUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/PartialUpdate',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskPartialUpdateRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/Retrieve',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRetrieveRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RetrieveByNameNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/RetrieveByNameNamespace',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRetrieveByNameNSRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/Stream',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskStreamRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/lara_django.lara_django_projects.TaskController/Update',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskRequest.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.TaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_projects.TaskController/UploadFile',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadChunk.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.FileUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadImage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/lara_django.lara_django_projects.TaskController/UploadImage',
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadChunk.SerializeToString,
            lara__django__projects__grpc_dot_v1_dot_lara__django__projects__pb2.ImageUploadInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
